Models
======

Fully executable scripts that implement published models used to simulate a set of empirical findings and/or
illustrate principles of neural and/or psychological function.

• `GilzenratModel`
